package ru.dbotthepony.kstarbound.client.render

import it.unimi.dsi.fastutil.longs.Long2ObjectAVLTreeMap
import it.unimi.dsi.fastutil.longs.Long2ObjectOpenHashMap
import ru.dbotthepony.kvector.arrays.Matrix3fStack
import ru.dbotthepony.kvector.arrays.Matrix4fStack
import java.util.function.Function

/**
 * Позволяет вызывать отрисовщики в определённой (послойной) последовательности
 */
class LayeredRenderer {
	private val layers = Long2ObjectAVLTreeMap<ArrayList<() -> Unit>>()

	fun add(layer: Long, renderer: () -> Unit) {
		layers.computeIfAbsent(layer, Function { ArrayList() }).add(renderer)
	}

	fun render() {
		for (list in layers.values) {
			for (renderer in list) {
				renderer.invoke()
			}
		}

		layers.clear()
	}
}
